@@ -34,6 +34,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 import php.java.bridge.Util;
+import php.java.bridge.http.IContextFactory;
 import php.java.servlet.CGIServlet;
 import php.java.servlet.PhpCGIServlet;
 
@@ -54,7 +55,7 @@ import php.java.servlet.PhpCGIServlet;
  * @see php.java.bridge.Util#DEFAULT_CGI_LOCATIONS
  * @author jostb
  */
-public class FastCGIServlet extends CGIServlet {
+public abstract class FastCGIServlet extends CGIServlet {
     /**
      * 
      */
@@ -267,7 +268,8 @@ public class FastCGIServlet extends CGIServlet {
     }
 
     protected class CGIEnvironment extends CGIServlet.CGIEnvironment {
-	ConnectionPool connectionPool;
+	private ConnectionPool connectionPool;
+    	public IContextFactory ctx;
 
 	protected CGIEnvironment(HttpServletRequest req, HttpServletResponse res, ServletContext context) {
 	    super(req, res, context);
@@ -347,7 +349,8 @@ public class FastCGIServlet extends CGIServlet {
 
     protected class CGIRunner extends CGIServlet.CGIRunner {
 
-	ConnectionPool connectionPool;
+	private ConnectionPool connectionPool;
+	protected IContextFactory ctx;
 	
 	/**
 	 * @param command
@@ -357,9 +360,10 @@ public class FastCGIServlet extends CGIServlet {
 	protected CGIRunner(CGIServlet.CGIEnvironment env) {
 	    super(env);
 	    connectionPool = ((CGIEnvironment)env).connectionPool;
+	    ctx = ((CGIEnvironment)env).ctx;
 	}
 
-	protected void doRun() throws IOException, ServletException {
+	protected void doExecute() throws IOException, ServletException {
 	    try {
 	        parseBody();
 	    } catch (ConnectionException ex) {
@@ -367,9 +371,9 @@ public class FastCGIServlet extends CGIServlet {
 	        parseBody();
 	    }
 	}
-	protected void run() throws IOException, ServletException {
+	protected void execute() throws IOException, ServletException {
 	    try {
-	        doRun();
+	        doExecute();
 	    } catch (ConnectException ex) {
 	        fcgiIsAvailable = false;
 	        if(Util.logLevel>1) {
@@ -388,7 +392,10 @@ public class FastCGIServlet extends CGIServlet {
 		  Util.logDebug("IOException caused by internet browser: " + e);
 		  Util.printStackTrace(e);
 	      }	      
-	      	throw new ServletException("IOException caused by internet browser", e);
+	      //throw new ServletException("IOException caused by internet browser", e);
+	    } finally {
+    		if(ctx!=null) ctx.release();
+    		ctx = null;
 	    }
 	    
 	}
@@ -457,7 +464,10 @@ public class FastCGIServlet extends CGIServlet {
 			i=0;
 		    }
 		}
-		natIn.close(); String phpFatalError = natIn.getError();
+		natIn.close(); 
+		String phpFatalError = natIn.checkError();
+		StringBuffer phpError = natIn.getError();
+		if (phpError!=null) Util.logMessage(phpError.toString());
 		natIn = null; connection = null;
 		
 		if(phpFatalError!=null) throw new RuntimeException(phpFatalError);
