@@ -1,12 +1,7 @@
 #!/usr/bin/php
 
 <?php
-if (!extension_loaded('java')) {
-  if (!(require_once("http://127.0.0.1:8080/JavaBridge/java/Java.inc"))) {
-    echo "java extension not installed.";
-    exit(2);
-  }
-}
+require_once ("java/Java.inc");
 function c1($s1, $o1) {
   echo "c1: $s1, $o1\n";
   // must display a php warning
