@@ -2,12 +2,7 @@
 
 <?php
 
-if (!extension_loaded('java')) {
-  if (!(require_once("http://127.0.0.1:8080/JavaBridge/java/Java.inc"))) {
-    echo "java extension not installed.";
-    exit(2);
-  }
-}
+require_once ("java/Java.inc");
 
 try {
   $here=realpath(dirname($_SERVER["SCRIPT_FILENAME"]));
@@ -31,7 +26,7 @@ if(!$here) $here=getcwd();
 
     $cause = $exception->getCause();
     echo "exception ".java_cast($cause,"S")." --> " . $cause->getID() . "\n";
-    return ($cause->getID() == 42) ? 0 : 3; 
+    return (java_values($cause->getID()) == 42) ? 0 : 3; 
   }
 } catch (exception $err) {
   print "unexpected: ".java_cast($err, "S")." \n";
